sphinx.ext.graphviz – Add Graphviz graphs — flask-peewee v0.1.0 documentation

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »

# `sphinx.ext.graphviz` – Add Graphviz graphs

New in version 0.6.

This extension allows you to embed Graphviz graphs in your documents.

It adds these directives:

`.. graphviz::`

  Directive to embed graphviz code. The input code for `dot` is given as the content. For example:

      .. graphviz::

         digraph foo {
            "bar" -> "baz";
         }

  In HTML output, the code will be rendered to a PNG or SVG image (see :confval:`graphviz_output_format`). In LaTeX output, the code will be rendered to an embeddable PDF file.

`.. graph::`

  Directive for embedding a single undirected graph. The name is given as a directive argument, the contents of the graph are the directive content. This is a convenience directive to generate `graph <name> { <content> }`.

  For example:

      .. graph:: foo

         "bar" -- "baz";

`.. digraph::`

  Directive for embedding a single directed graph. The name is given as a directive argument, the contents of the graph are the directive content. This is a convenience directive to generate `digraph <name> { <content> }`.

  For example:

      .. digraph:: foo

         "bar" -> "baz" -> "quux";

New in version 1.0: All three directives support an `alt` option that determines the image’s alternate text for HTML output. If not given, the alternate text defaults to the graphviz code.

There are also these new config values:

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »